@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "3.3.0"
+#define BARESIP_VERSION "3.5.1"
 
 
 #ifndef NET_MAX_NS
@@ -1380,6 +1380,8 @@ int   video_set_fullscreen(struct video *v, bool fs);
 void  video_vidsrc_set_device(struct video *v, const char *dev);
 int   video_set_source(struct video *v, const char *name, const char *dev);
 void  video_set_devicename(struct video *v, const char *src, const char *disp);
+const char *video_get_src_dev(const struct video *v);
+const char *video_get_disp_dev(const struct video *v);
 int   video_debug(struct re_printf *pf, const struct video *v);
 struct stream *video_strm(const struct video *v);
 const struct vidcodec *video_codec(const struct video *vid, bool tx);
@@ -1429,7 +1431,6 @@ int  stream_start_mediaenc(struct stream *strm);
 int  stream_start_rtcp(const struct stream *strm);
 int  stream_enable(struct stream *strm, bool enable);
 int  stream_enable_tx(struct stream *strm, bool enable);
-int stream_open_natpinhole(struct stream *strm);
 void stream_mnat_attr(struct stream *strm, const char *name,
 		      const char *value);
 void stream_set_session_handlers(struct stream *strm,
@@ -1701,12 +1702,12 @@ int  peerconnection_new(struct peer_connection **pcp,
 		        peerconnection_gather_h *gatherh,
 		        peerconnection_estab_h,
 		        peerconnection_close_h *closeh, void *arg);
-int  peerconnection_add_audio_track(struct peer_connection *pc,
-			 const struct config *cfg,
-			 struct list *aucodecl);
-int  peerconnection_add_video_track(struct peer_connection *pc,
-			 const struct config *cfg,
-			 struct list *vidcodecl);
+int peerconnection_add_audio_track(struct peer_connection *pc,
+				   const struct config *cfg,
+				   struct list *aucodecl, enum sdp_dir dir);
+int peerconnection_add_video_track(struct peer_connection *pc,
+				   const struct config *cfg,
+				   struct list *vidcodecl, enum sdp_dir dir);
 int  peerconnection_set_remote_descr(struct peer_connection *pc,
 				    const struct session_description *sd);
 int  peerconnection_create_offer(struct peer_connection *sess,
